@@ -17,12 +17,13 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+#include <libgnome/libgnome.h>
 #include <syslog.h>
 #include <signal.h>
 #include <sys/wait.h>
 #include <X11/Xauth.h>
 #include <sys/types.h>
+#include <unistd.h>
 #include <fcntl.h>
 
 #include "gdm.h"
@@ -35,8 +36,6 @@
 #include "choose.h"
 #include "gdm-net.h"
 
-static const gchar RCSid[]="$Id: display.c,v 1.22 2001/09/11 03:26:01 jirka Exp $";
-
 /* External vars */
 extern gboolean GdmXdmcp;
 extern gint sessions;
@@ -89,15 +88,27 @@ gdm_display_check_loop (GdmDisplay *disp)
   /* If we've tried too many times we bail out. i.e. this means we
    * tried too many times in the 90-second period.
    */
-  if (disp->retry_count > 4)
-    {
-      gdm_error (_("Failed to start the display server several times in a short time period; disabling display %s"), disp->name);
-      disp->disabled = TRUE;
+  if (disp->retry_count > 4) {
+	  /* This means we have no clue what's happening,
+	   * it's not X server crashing as we would have
+	   * cought that elsewhere.  Things are just
+	   * not working out, so tell the user */
+	  char *s = g_strdup_printf (_("Failed to start the display server "
+				       "several times in a short time period; "
+				       "disabling display %s"), disp->name);
+	  /* only display a dialog box if this is a local display */
+	  if (disp->type == TYPE_LOCAL ||
+	      disp->type == TYPE_FLEXI)
+		  gdm_text_message_dialog (s);
+	  gdm_error ("%s", s);
+	  g_free (s);
 
-      gdm_debug ("Failed to start X server after several retries; aborting.");
-      
-      return FALSE;
-    }
+	  disp->disabled = TRUE;
+
+	  gdm_debug ("Failed to start X server after several retries; aborting.");
+
+	  return FALSE;
+  }
   
   /* At least 8 seconds between start attempts,
    * so you can try to kill gdm from the console
@@ -132,7 +143,7 @@ gdm_display_check_loop (GdmDisplay *disp)
 gboolean 
 gdm_display_manage (GdmDisplay *d)
 {
-    sigset_t mask, omask;
+    pid_t pid;
     int i;
 
     if (!d) 
@@ -143,22 +154,23 @@ gdm_display_manage (GdmDisplay *d)
     if ( ! gdm_display_check_loop (d))
 	    return FALSE;
 
+    gdm_sigchld_block_push ();
+
     /* If we have an old slave process hanging around, kill it */
     if (d->slavepid) {
-	sigemptyset (&mask);
-	sigaddset (&mask, SIGCHLD);
-	sigprocmask (SIG_BLOCK, &mask, &omask); 
-
-	if (kill (d->slavepid, SIGINT) == 0)
-		waitpid (d->slavepid, 0, 0);
-	d->slavepid = 0;
-
-	sigprocmask (SIG_SETMASK, &omask, NULL);
+	    if (kill (d->slavepid, SIGINT) == 0)
+		    waitpid (d->slavepid, 0, 0);
+	    d->slavepid = 0;
     }
 
     /* Fork slave process */
-    gdm_safe_fork (&(d->slavepid));
-    switch (d->slavepid) {
+    gdm_sigterm_block_push ();
+    pid = d->slavepid = fork ();
+    gdm_sigterm_block_push ();
+
+    gdm_sigchld_block_pop ();
+
+    switch (pid) {
 
     case 0:
 	setpgid (0, 0);
@@ -192,7 +204,8 @@ gdm_display_manage (GdmDisplay *d)
 	    gdm_server_stop (d);
 	    /* we expect to return after the session finishes */
 	    _exit (DISPLAY_REMANAGE);
-	} else if (d->type == TYPE_XDMCP && d->dispstat == XDMCP_MANAGED) {
+	} else if (d->type == TYPE_XDMCP &&
+		   d->dispstat == XDMCP_MANAGED) {
 	    gdm_slave_start (d);
 	    gdm_server_stop (d);
 	    /* we expect to return after the session finishes */
@@ -213,12 +226,12 @@ gdm_display_manage (GdmDisplay *d)
 
     default:
 	gdm_debug ("gdm_display_manage: Forked slave: %d",
-		   (int)d->slavepid);
+		   (int)pid);
 	break;
     }
 
     if (SERVER_IS_LOCAL (d)) {
-	    d->dispstat = DISPLAY_SUCCESS;
+	    d->dispstat = DISPLAY_ALIVE;
     }
 
     /* reset sleep to 0 */
