@@ -20,30 +20,19 @@
 #define GDM_ERRORGUI_H
 
 #include "gdm.h"
+#include <gtk/gtkmessagedialog.h>
 
-/* this includes the actual gtk interface */
-void		gdm_run_errorgui	(const char *error,
-					 const char *dialog_type,
-					 int screenx,
-					 int screeny,
-					 int screenwidth,
-					 int screenheight);
-/* this spawns self with the argument to run the above */
 void		gdm_error_box		(GdmDisplay *d,
-					 const char *dialog_type,
+					 GtkMessageType type,
 					 const char *error);
 
-char *		gdm_run_failsafe_question(const char *question,
-					  gboolean echo,
-					  int screenx,
-					  int screeny,
-					  int screenwidth,
-					  int screenheight);
-/* this spawns self with the argument to run the above */
 char *		gdm_failsafe_question	(GdmDisplay *d,
 					 const char *question,
 					 gboolean echo);
 
+gboolean	gdm_failsafe_yesno	(GdmDisplay *d,
+					 const char *question);
+
 #endif /* GDM_ERRORGUI_H */
 
 /* EOF */
