@@ -18,7 +18,8 @@
  * 
  */
 
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
 #include <ctype.h>
 #include <unistd.h>
@@ -30,7 +31,7 @@
 /* Some macros to make setting the tens of GtkEntry and GtkSpinButtons much simpler. 
  * It also makes the code a lot more readable too.
  */
-GtkWidget *get_widget(gchar *widget_name);
+GtkWidget *get_widget(const gchar *widget_name);
 
 
 typedef struct _GdmConfigSession GdmConfigSession;
@@ -75,10 +76,6 @@ struct _GdmConfigSession {
            gnome_icon_entry_set_icon(GNOME_ICON_ENTRY(get_widget(icon_name)), \
                               (char *)value);
 
-#define gdm_font_set(font_name, value) \
-        if (value) \
-           gnome_font_picker_set_font_name(GNOME_FONT_PICKER(get_widget(font_name)), \
-                                           (char *)value);
 #define gdm_color_set(picker_name, value) \
         if (value) { \
 	   GdkColor color; \
@@ -105,7 +102,7 @@ struct _GdmConfigSession {
 
 #define gdm_icon_write(icon_name, key) \
 	{ \
-	char *icon = hack_icon_entry_get_icon(GNOME_ICON_ENTRY(get_widget(icon_name))); \
+	char *icon = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(get_widget(icon_name))); \
         if (icon != NULL) \
            gnome_config_set_string(key, icon); \
         else \
@@ -113,9 +110,6 @@ struct _GdmConfigSession {
 	g_free (icon); \
 	}
 
-#define gdm_font_write(picker_name, key) \
-        gnome_config_set_string(key, gnome_font_picker_get_font_name(GNOME_FONT_PICKER(get_widget(picker_name))));
-
 #define gdm_color_write(picker_name, key) \
 	{ \
 		char *value; \
@@ -176,8 +170,16 @@ change_background_sensitivity_none     (GtkButton       *button,
 void
 set_face_sensitivity                   (GtkButton       *button,
                                         gpointer         user_data);
-void handle_server_add_or_edit         (gchar           *string,
-					gpointer         user_data);
+void add_new_server_def (GtkButton *button, gpointer user_data);
+void edit_selected_server_def (GtkButton *button, gpointer user_data);
+void delete_selected_server_def (GtkButton *button, gpointer user_data);
+void make_server_def_default (GtkButton *button, gpointer user_data);
+void record_selected_server_def (GtkCList *clist,
+				 gint row,
+				 gint column,
+				 GdkEventButton *event,
+				 gpointer user_data);
+
 void
 add_new_server                         (GtkButton       *button,
                                         gpointer         user_data);
