@@ -19,7 +19,8 @@
  */
 
 #include "config.h"
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <gdk/gdkx.h>
 #include <X11/Xauth.h>
 
@@ -42,6 +43,7 @@ static GSList *xservers = NULL;
 static gboolean got_standard = FALSE;
 static gboolean use_xnest = FALSE;
 static gboolean authenticate = FALSE;
+static gboolean no_lock = FALSE;
 static const char *send_command = NULL;
 static const char *server = NULL;
 static const char *chosen_server = NULL;
@@ -54,12 +56,25 @@ do_command (int fd, const char *command, gboolean get_response)
 	GString *str;
 	char buf[1];
 	char *cstr;
+	int ret;
+#ifndef MSG_NOSIGNAL
+	void (*old_handler)(int);
+#endif
 
 	if (debug)
 		g_print ("Sending command: '%s'\n", command);
 
 	cstr = g_strdup_printf ("%s\n", command);
-	if (send (fd, cstr, strlen (cstr), MSG_NOSIGNAL) < 0)
+
+#ifdef MSG_NOSIGNAL
+	ret = send (fd, cstr, strlen (cstr), MSG_NOSIGNAL);
+#else
+	old_handler = signal (SIGPIPE, SIG_IGN);
+	ret = send (fd, cstr, strlen (cstr), 0);
+	signal (SIGPIPE, old_handler);
+#endif
+
+	if (ret < 0)
 		return NULL;
 
 	if ( ! get_response)
@@ -182,7 +197,7 @@ get_display (void)
 	static char *display = NULL;
 
 	if (display == NULL) {
-		display = g_strdup (gdk_display_name);
+		display = g_strdup (gdk_get_display ());
 		if (display == NULL) {
 			display = g_strdup (g_getenv ("DISPLAY"));
 			if (display == NULL) /*eek!*/ {
@@ -194,6 +209,84 @@ get_display (void)
 	return display;
 }
 
+static char *
+get_dispnum (void)
+{
+	static char *number = NULL;
+
+	if (number == NULL) {
+		char *p;
+		number = g_strdup (get_display ());
+
+		/* whee! handles even DECnet crap */
+		number = strchr (number, ':');
+		if (number != NULL) {
+			while (*number == ':') {
+				number++;
+			}
+			p = strchr (number, '.');
+			if (p != NULL)
+				*p = '\0';
+		} else {
+			number = "0";
+		}
+	}
+
+	return number;
+}
+
+/* This just gets a cookie of MIT-MAGIC-COOKIE-1 type */
+static char *
+get_a_cookie (void)
+{
+	FILE *fp;
+	char *number;
+	char *cookie = NULL;
+	Xauth *xau;
+
+	fp = fopen (XauFileName (), "r");
+	if (fp == NULL) {
+		return NULL;
+	}
+
+	number = get_dispnum ();
+
+	cookie = NULL;
+
+	while ((xau = XauReadAuth (fp)) != NULL) {
+		int i;
+		GString *str;
+
+		/* Just find the FIRST magic cookie, that's what gdm uses */
+		if (xau->number_length != strlen (number) ||
+		    strncmp (xau->number, number, xau->number_length) != 0 ||
+		    /* gdm sends MIT-MAGIC-COOKIE-1 cookies of length 16,
+		     * so just do those */
+		    xau->name_length != strlen ("MIT-MAGIC-COOKIE-1") ||
+		    strncmp (xau->name, "MIT-MAGIC-COOKIE-1",
+			     xau->name_length) != 0) {
+			XauDisposeAuth (xau);
+			continue;
+		}
+
+		str = g_string_new (NULL);
+
+		for (i = 0; i < xau->data_length; i++) {
+			g_string_sprintfa (str, "%02x",
+					   (guint)(guchar)xau->data[i]);
+		}
+
+		XauDisposeAuth (xau);
+
+		cookie = str->str;
+		g_string_free (str, FALSE);
+		break;
+	}
+	fclose (fp);
+
+	return cookie;
+}
+
 static char *
 get_auth_cookie (void)
 {
@@ -213,17 +306,7 @@ get_auth_cookie (void)
 		return NULL;
 	}
 
-	number = get_display ();
-
-	/* whee! handles even DECnet crap */
-	number = strchr (number, ':');
-	if (number != NULL) {
-		while (*number == ':') {
-		       number++;
-		}
-	} else {
-		number = "0";
-	}
+	number = get_dispnum ();
 
 	cookie = NULL;
 
@@ -238,12 +321,13 @@ get_auth_cookie (void)
 		 * logins, though those will not pass by gdm itself of
 		 * course) */
 		if (xau->family != FamilyLocal ||
-		    xau->number == NULL ||
+		    xau->number_length != strlen (number) ||
 		    strncmp (xau->number, number, xau->number_length) != 0 ||
 		    /* gdm sends MIT-MAGIC-COOKIE-1 cookies of length 16,
 		     * so just do those */
 		    xau->name_length != strlen ("MIT-MAGIC-COOKIE-1") ||
-		    strncmp (xau->name, "MIT-MAGIC-COOKIE-1", xau->name_length) != 0 ||
+		    strncmp (xau->name, "MIT-MAGIC-COOKIE-1",
+			     xau->name_length) != 0 ||
 		    xau->data_length != 16) {
 			XauDisposeAuth (xau);
 			continue;
@@ -252,7 +336,8 @@ get_auth_cookie (void)
 		buffer[0] = '\0';
 		for (i = 0; i < 16; i++) {
 			char sub[3];
-			g_snprintf (sub, sizeof (sub), "%02x", (guint)(guchar)xau->data[i]);
+			g_snprintf (sub, sizeof (sub), "%02x",
+				    (guint)(guchar)xau->data[i]);
 			strcat (buffer, sub);
 		}
 
@@ -414,6 +499,7 @@ choose_server (void)
 struct poptOption options [] = {
 	{ "command", 'c', POPT_ARG_STRING, &send_command, 0, N_("Send the specified protocol command to gdm"), N_("COMMAND") },
 	{ "xnest", 'n', POPT_ARG_NONE, &use_xnest, 0, N_("Xnest mode"), NULL },
+	{ "no-lock", 'l', POPT_ARG_NONE, &no_lock, 0, N_("Do not lock current screen"), NULL },
 	{ "debug", 'd', POPT_ARG_NONE, &debug, 0, N_("Debugging output"), NULL },
 	{ "authenticate", 'a', POPT_ARG_NONE, &authenticate, 0, N_("Authenticate before running --command"), NULL },
 	POPT_AUTOHELP
@@ -496,11 +582,22 @@ main (int argc, char *argv[])
 	}
 
 	if (use_xnest) {
-		command = g_strdup_printf (GDM_SUP_FLEXI_XNEST
-					   " %s %s",
+		char *cookie = get_a_cookie ();
+		if (cookie == NULL) {
+			dialog = gnome_warning_dialog
+				(_("You do not seem to have authentication "
+				   "needed be for this operation.  Perhaps "
+				   "your .Xauthority file is not set up "
+				   "correctly."));
+			gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+			return 1;
+		}
+		command = g_strdup_printf (GDM_SUP_FLEXI_XNEST " %s %s %s",
 					   get_display (),
+					   cookie,
 					   XauFileName ());
-		version = "2.2.4.0";
+		g_free (cookie);
+		version = "2.2.4.2";
 		auth_cookie = NULL;
 	} else {
 		auth_cookie = get_auth_cookie ();
@@ -527,6 +624,18 @@ main (int argc, char *argv[])
 	ret = call_gdm (command, auth_cookie, version, 5);
 	if (ret != NULL &&
 	    strncmp (ret, "OK ", 3) == 0) {
+
+		/* if we switched to a different screen as a result of this,
+		 * lock the current screen */
+		if ( ! no_lock && ! use_xnest) {
+			char *argv[3] = {"xscreensaver-command", "-lock", NULL};
+			if (gnome_execute_async (g_get_home_dir (), 2, argv) < 0)
+				g_warning (_("Can't lock screen"));
+			argv[1] = "-throttle";
+			if (gnome_execute_async (g_get_home_dir (), 2, argv) < 0)
+				g_warning (_("Can't disable xscreensaver display hacks"));
+		}
+
 		/* all fine and dandy */
 		return 0;
 	}
@@ -562,9 +671,9 @@ main (int argc, char *argv[])
 				    "it is likely that gdm is badly "
 				    "configured.");
 	} else if (strncmp (ret, "ERROR 100 ", strlen ("ERROR 100 ")) == 0) {
-		message = _("You do not seem to be logged in on the "
-			    "console.  Starting a new login only "
-			    "works correctly on the console.");
+		message = _("You do not seem to have authentication needed "
+			    "be for this operation.  Perhaps your .Xauthority "
+			    "file is not set up correctly.");
 	} else {
 		message = _("Unknown error occured.");
 	}
