@@ -19,7 +19,8 @@
  */
 
 #include "config.h"
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <string.h>
 
 #include "gdmlanguages.h"
@@ -31,6 +32,10 @@ struct _Language {
 	int found;
 };
 
+/* Note: these should NOT include the encodings, this is just a translation
+ * matrix for language_country names.  This is NOT a list of available
+ * languages, just their names and where they are placed in the menu.
+ * The available languages come from the supplied locale.alias */
 static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Catalan"), "ca_ES", 0 },
@@ -100,6 +105,8 @@ static Language languages [] = {
 	{ N_("N-Z|Swedish"), "sv_SE", 0 },
 	/*Note translate the N-Z to the N-Z you used in the group label */
 	{ N_("N-Z|Turkish"), "tr_TR", 0 },
+	/*Note translate the N-Z to the N-Z you used in the group label */
+	{ N_("N-Z|Ukrainian"), "uk_UA", 0 },
 	/* This is the POSIX/C locale for english, should really be in Other */
 	{ N_("Other|POSIX/C English"), "C", 0 },
 	{ NULL, NULL }
